==> kie-wb-distributions-7.5.0.Final-project-sources.tar.gz: kie-wb-distributions-7.5.0.Final/kie-wb-parent/kie-wb-monitoring-webapp/src/main/java/org/kie/workbench/client/resources/i18n/NavigationConstants.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.client.resources.i18n;

import com.google.gwt.core.client.GWT;
import com.google.gwt.i18n.client.Messages;

/**
 * This uses GWT to provide client side compile time resolving of locales. See:
 * http://code.google.com/docreader/#p=google-web-toolkit-doc-1-5&s=google-web-
 * toolkit-doc-1-5&t=DevGuideInternationalization (for more information).
 * <p/>
 * Each method name matches up with a key in Constants.properties (the
 * properties file can still be used on the server). To use this, use
 * <code>GWT.create(Constants.class)</code>.
 */
public interface NavigationConstants
        extends
        Messages {

    NavigationConstants INSTANCE = GWT.create(NavigationConstants.class);

    String navTreeWorkbenchName();

    String navTreeDesignName();

    String navTreeDashboardsName();

    String navTreeDevOpsName();

    String navTreeDeploymentsName();

    String navTreeExecutionServersName();

    String navTreeManageName();

    String navTreeProcessDefinitionsName();

    String navTreeProcessInstancesName();

    String navTreeTasksAdministrationName();

    String navTreeJobsName();

    String navTreeExecutionErrorsName();

    String navTreeTrackName();

    String navTreeTasksListName();

    String navTreeProcessesAndTasksDashboardName();

    String navTreeBusinessDashboardsName();

    String navTreeWorkbenchDescr();

    String navTreeDesignDescr();

    String navTreeDashboardsDescr();

    String navTreeDevOpsDescr();

    String navTreeDeploymentsDescr();

    String navTreeExecutionServersDescr();

    String navTreeManageDescr();

    String navTreeProcessDefinitionsDescr();

    String navTreeProcessInstancesDescr();

    String navTreeTasksAdministrationDescr();

    String navTreeJobsDescr();

    String navTreeExecutionErrorsDescr();

    String navTreeTrackDescr();

    String navTreeTasksListDescr();

    String navTreeProcessesAndTasksDashboardDescr();

    String navTreeBusinessDashboardsDescr();
}

==> kie-wb-distributions-7.7.0.Final-project-sources.tar.gz: kie-wb-distributions-7.7.0.Final/kie-wb-parent/kie-wb-monitoring-webapp/src/main/java/org/kie/workbench/client/resources/i18n/NavigationConstants.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.client.resources.i18n;

import com.google.gwt.core.client.GWT;
import com.google.gwt.i18n.client.Messages;

/**
 * This uses GWT to provide client side compile time resolving of locales. See:
 * http://code.google.com/docreader/#p=google-web-toolkit-doc-1-5&s=google-web-
 * toolkit-doc-1-5&t=DevGuideInternationalization (for more information).
 * <p/>
 * Each method name matches up with a key in Constants.properties (the
 * properties file can still be used on the server). To use this, use
 * <code>GWT.create(Constants.class)</code>.
 */
public interface NavigationConstants
        extends
        Messages {

    NavigationConstants INSTANCE = GWT.create(NavigationConstants.class);

    String navTreeWorkbenchName();

    String navTreeDesignName();

    String navTreePageAuthoringName();

    String navTreeDeployName();

    String navTreeDeploymentsName();

    String navTreeExecutionServersName();

    String navTreeManageName();

    String navTreeProcessDefinitionsName();

    String navTreeProcessInstancesName();

    String navTreeTasksName();

    String navTreeJobsName();

    String navTreeExecutionErrorsName();

    String navTreeTrackName();

    String navTreeTaskInboxName();

    String navTreeProcessReportName();

    String navTreeTaskReportName();

    String navTreeWorkbenchDescr();

    String navTreeDesignDescr();

    String navTreePageAuthoringDescr();

    String navTreeDeployDescr();

    String navTreeDeploymentsDescr();

    String navTreeExecutionServersDescr();

    String navTreeManageDescr();

    String navTreeProcessDefinitionsDescr();

    String navTreeProcessInstancesDescr();

    String navTreeTasksDescr();

    String navTreeJobsDescr();

    String navTreeExecutionErrorsDescr();

    String navTreeTrackDescr();

    String navTreeTaskInboxDescr();

    String navTreeProcessReportDescr();

    String navTreeTaskReportDescr();
}
